@@ -585,7 +585,7 @@ void KigWidget::zoomArea()
   KigInputDialog::getTwoCoordinates( i18n( "Select Zoom Area" ),
         i18n( "Select the zoom area by entering the coordinates<br />"
               "of the upper left corner and the lower right corner." ) +
-        QString::fromLatin1( "<br />" ) +
+        QLatin1String( "<br />" ) +
         mpart->document().coordinateSystem().coordinateFormatNoticeMarkup(),
         this, &ok, mpart->document(), &tl, &br );
   if ( ok )
